;----------------------------------------------------------------------------------
; Sample AutoHotkey script which resets settings after each sequence
; Switches the booth back to stills mode and a single color print.
;
; AutoHotKey is free and can be downloaded from:
; http://www.autohotkey.com
;
; This script works with:
; DSLR Remote Pro for Windows v1.9.1 or later
; NKRemote v1.4 or later
; PSRemote v1.9 or later
;
; This script comes with no warranty or support whatsoever and may
; be freely copied or modified as required.
;
; Written by Chris Breeze, www.breezesys.com
;
; UPDATES:
; 20 Feb 2011: Added resetting back to stills photo booth mode if video
;              booth mode was used (DSLR Remote Pro for Windows v2.1 onwards)
; 1 Apr 2011:  Activate window if not already active when ready screen is displayed
;              to avoid problems with input focus being lost
;----------------------------------------------------------------------------------
#SingleInstance force

; loop forever monitoring the status of the photobooth screen by looking
; at the window title which is in the form:
; Breeze Systems Photobooth - <screen_pathname>
LookForReady = 1
Loop
{
	IfWinExist, Breeze Systems Photobooth
	{
		WinGetTitle, Title, Breeze Systems Photobooth
		if Title contains ready.jpg
		{
			; ensure the photobooth window is active when ready screen is displayed to
			; avoid problems with keyboard input focus being lost
			IfWinNotActive, Breeze Systems Photobooth
			{
				WinActivate, Breeze Systems Photobooth
			}

			; Photobooth is displaying ready screen - are we looking for ready.jpg?
			if LookForReady
			{
				; yes, photobooth has just switched from processing.jpg to ready.jpg
				LookForReady = 0
				WinActivate, Breeze Systems Photobooth
				if Title contains video_ready
				{
					; switch from video booth mode back to stills photo booth mode
					Send ^p
				}
				else
				{
					; Switch back to color mode
					Send ^c

					; reset the number of copies back to 1
					Send ^1
				}
			}
		}
		else if Title contains processing.jpg
		{
			; Photobooth is displaying ready screen - start looking for ready.jpg
			LookForReady = 1
		}
	}
	else
	{
		LookForReady = 1
	}
	Sleep 100	; sleep for 1/10th sec to avoid hogging the processor
}
Return
